@@ -13,20 +13,21 @@ fun_load_genome <- function(organism) {
       stop("Install BSgenome.Hsapiens.UCSC.hg38 package.",
            call. = FALSE)
     }
-    return(BSgenome.Hsapiens.UCSC.hg38::BSgenome.Hsapiens.UCSC.hg38)
-  } else if (organism %in% c("Mouse", "mm10")) {
+    ref_genome <- BSgenome.Hsapiens.UCSC.hg38::BSgenome.Hsapiens.UCSC.hg38
+    } else if (organism %in% c("Mouse", "mm10")) {
     if (!requireNamespace("BSgenome.Mmusculus.UCSC.mm10", quietly = TRUE)) {
       stop("Install BSgenome.Mmusculus.UCSC.mm10 package.",
            call. = FALSE)
     }
-    return(BSgenome.Mmusculus.UCSC.mm10::BSgenome.Mmusculus.UCSC.mm10)
+    ref_genome <- BSgenome.Mmusculus.UCSC.mm10::BSgenome.Mmusculus.UCSC.mm10
   } else if (organism %in% c("hg19")) {
     if (!requireNamespace("BSgenome.Hsapiens.UCSC.hg19", quietly = TRUE)) {
       stop("Install BSgenome.Hsapiens.UCSC.hg19 package.",
            call. = FALSE)
     }
-    return(BSgenome.Hsapiens.UCSC.hg19::BSgenome.Hsapiens.UCSC.hg19)
+    ref_genome <- BSgenome.Hsapiens.UCSC.hg19::BSgenome.Hsapiens.UCSC.hg19
   }
+  return(ref_genome)
 }
 
 # The following block is used by usethis to automatically manage
